@@ -1,4 +1,4 @@
-from typing import Type, Protocol, Dict
+from typing import Any, Type, Protocol, Dict
 from xoa_converter import exceptions
 from xoa_converter import types
 from .rfc2544.adapter import Converter2544
@@ -7,7 +7,7 @@ from .rfc2889.adapter import Converter2889
 
 class XoaConverter(Protocol):
     def __init__(self, source_config: str) -> None: ...
-    def gen(self) -> Dict: ...
+    def gen(self) -> Dict[str, Any]: ...
 
 
 def get_converter(test_suite_type: types.TestSuiteType) -> Type[XoaConverter]:
